/*
 * DefaultNodeBehavior.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.util.Vector;

/** 
 * This is the default NodeBehavior.  It isn't very good, as it drops
 * packets and generally is unreliable.  A better implementation is
 * IntermediateNode<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @see IntermediateNode
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: DefaultNodeBehavior.java,v 1.3 1999/08/04 09:08:51 jsmthng Exp $ 
 */
class DefaultNodeBehavior implements NodeBehavior {
  
  private Object o = null;
  private int num_attempts = 0;
  private boolean found;
  private int out_number, in_number;
  private int counter;
  
  public void transmitPacket(InputChannelVector inputChannels,
		  OutputChannelVector outputChannels ) {
    
    int numInputChannels = inputChannels.size();
    int numOutputChannels = outputChannels.size();
    // punt if we can't output this stuff anywhere or if we don't have stuff to get
    if ((numInputChannels == 0) || (numOutputChannels == 0)) { return; }
    
    // randomly decide to not do anything
    if (Math.random() < 0.5) return;
    
    this.found = false;
    this.num_attempts = 0;
    
    while(!this.found) {
      this.num_attempts++;
      if (this.num_attempts > 20) break;
      this.in_number = (int)(Math.random() * numInputChannels);
      try { 
	this.o = 
	  inputChannels.elementAt(this.in_number).readObject(); }  // ()?
      catch(ChannelEmptyException exc) { continue; } 
      catch(ChannelDisabledException exc2) { continue; }
      this.found = true;
    }
    
    if (!this.found) return; 
    this.found = false;
    this.num_attempts = 0;
    
    while (!this.found) {
      this.num_attempts++;
      if (this.num_attempts > 20) break;;
      this.out_number = (int)(Math.random() * numOutputChannels);
      try { 
		outputChannels.elementAt(this.out_number).writeObject(this.o); } // ()?
      catch(ChannelFullException exc3) { continue; }
      catch(ChannelDisabledException exc4) { continue; }
      this.found = true;
    }
  }
}

/*
 * $Log: DefaultNodeBehavior.java,v $
 * Revision 1.3  1999/08/04 09:08:51  jsmthng
 * Added javadoc comments to InputChannelVector and OutputChannelVector;
 * finished updating the rest of the nodeNet package to reflect new
 * changes in name and code.
 *
 * Modified index.html to reflect the new nodeNet code, as well as to
 * clarify some parts of the problem set.
 *
 * Revision 1.1  1999/07/30 01:09:20  jsmthng
 * Renaming BinSort package to nodeNet; moving directories and files as
 * necessary.
 *
 * Revision 1.4  1998/08/12 19:29:33  tparnell
 * Another pass after comments from las & natashao.  Added support to
 * dynamically add NodeBehaviors.  Add keyboard shortcuts to menus.  Added
 * workaround to jdk bug relating to lighweight components.  Misc other
 * bugfixes.
 *
 * Revision 1.3  1998/08/10 17:45:50  tparnell
 * Revision to use JDK1.2 and Swing.  Redesign of GUI.  Removed old kludge
 * for file I/O and replaced with object serialization.  Channel no longer
 * requires animacy.  Removed unnessary dependencies between classes.
 * Added ability to configure channel's latency and capacity.  Added
 * javadoc to all files.  General code cleanup.
 *
 */