/*
 * GeneratorNodeBehavior.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.util.Vector;

/**
 * This class is the NodeBehavior for gererator godes.  It defines the
 * transmitPacket method.<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: GeneratorNodeBehavior.java,v 1.3 1999/08/04 09:08:51 jsmthng Exp $
 */
class GeneratorNodeBehavior implements NodeBehavior, CountingNodeBehavior {

  private int out_number;
  private int num_created = 0;
  private int spacing = 10;
    
  public void transmitPacket( InputChannelVector inputChannels,
		   OutputChannelVector outputChannels ) {
		     
    int numInputStreams = inputChannels.size();
    int numOutputStreams = outputChannels.size();
	
    spacing = ++spacing % 10000;

    if ((numOutputStreams == 0) || (spacing  % 10) != 0) return;
	
    out_number = (int)(Math.random() * numOutputStreams);
	    
    try {
      outputChannels.elementAt(out_number).writeObject(new Object()); // ()?
      num_created += 1;
    }
    catch(ChannelFullException exc) {}
    catch(ChannelDisabledException exc2) {}
  }

  public int getCount() { return num_created; }
  public void resetCount() { this.num_created = 0; }

  public void setFrequency(int freq) {
    if (freq < 1) spacing = 1;
    else if (freq > 50) spacing = 50;
    else spacing = freq;
  }
}

/*
 * $Log: GeneratorNodeBehavior.java,v $
 * Revision 1.3  1999/08/04 09:08:51  jsmthng
 * Added javadoc comments to InputChannelVector and OutputChannelVector;
 * finished updating the rest of the nodeNet package to reflect new
 * changes in name and code.
 *
 * Modified index.html to reflect the new nodeNet code, as well as to
 * clarify some parts of the problem set.
 *
 * Revision 1.1  1999/07/30 01:09:20  jsmthng
 * Renaming BinSort package to nodeNet; moving directories and files as
 * necessary.
 *
 * Revision 1.4  1998/08/12 19:29:34  tparnell
 * Another pass after comments from las & natashao.  Added support to
 * dynamically add NodeBehaviors.  Add keyboard shortcuts to menus.  Added
 * workaround to jdk bug relating to lighweight components.  Misc other
 * bugfixes.
 *
 * Revision 1.3  1998/08/10 17:45:50  tparnell
 * Revision to use JDK1.2 and Swing.  Redesign of GUI.  Removed old kludge
 * for file I/O and replaced with object serialization.  Channel no longer
 * requires animacy.  Removed unnessary dependencies between classes.
 * Added ability to configure channel's latency and capacity.  Added
 * javadoc to all files.  General code cleanup.
 *
 */
