/*
 * InputChannelVector.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1997 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.util.*;

/**
 * InputChannelVector is something which acts like a <code>Vector</code>
 * of <code>InputChannel</code>s instead of Objects.<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: InputChannelVector.java,v 1.2 1999/08/04 09:08:52 jsmthng Exp $ 
 */
public class InputChannelVector {
	
	private Vector myVector;

	/**
	 * Constructs a new InputChannelVector.
	 */
	public InputChannelVector( )
	{
		this.myVector = new Vector( );
	}
	
	/**
	 * Adds an object to the InputChannelVector.
	 */
	public final synchronized void addElement( Object obj )
	{
		this.myVector.addElement( obj );
	}
	
	/**
	 * Checks to see if it contains an element.
	 */	
	public final boolean contains( Object elem )
	{
		return this.myVector.contains( elem );
	}
	
	/**
	 * Returns the InputChannel at a certain index.
	 *
	 * @param index index of the InputChannel being looked up
	 */
	public final synchronized InputChannel elementAt( int index )
	{
		return (InputChannel)this.myVector.elementAt( index );
	}
			
	
	/**
	 * Transforms InputChannelVector into yet another type
	 * of collection of objects, called an Enumeration.
	 */
	public final synchronized Enumeration elements( )
	{
		return this.myVector.elements( );
	}
	
	/**
	 * Returns the first InputChannel in the InputChannelVector.
	 */
	public final synchronized InputChannel firstElement( )
	{
		return (InputChannel)this.myVector.firstElement( );
	}
	
	/**
	 * Returns true if the InputChannelVector is empty.
	 */
	public final boolean isEmpty( )
	{
		return this.myVector.isEmpty( );
	}
	
	/**
	 * Returns the last InputChannel in the InputChannelVector.
	 */
	public final synchronized InputChannel lastElement( )
	{
		return (InputChannel)this.myVector.lastElement( );
	}
	
	/**
	 * Removes all elements from the InputChannelVector.
	 */	
	public final synchronized void removeAllElements( )
	{
		this.myVector.removeAllElements( );
	}
	
	/**
	 * Removes a specific element from the InputChannelVector.
	 *
	 * @param obj the object being removed
	 */
	public final synchronized boolean removeElement( Object obj )
	{
		return this.myVector.removeElement( obj );
	}
	
	/**
	 * Returns the size of the InputChannelVector.
	 */
	public final int size( )
	{
		return this.myVector.size( );
	}
	
}

/*
 * $Log:
 */