/*
 * IntermediateNodeBehavior.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.io.*;
import java.util.Vector;

/**
 * This is an improved version of the DefaultNode.
 * It does not drop packets and chooses judiciously among
 * available inputs and outputs.<p>
 * 
 * Copyright (c) 1998 Massachusetts Institute of Technology
 * 
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: IntermediateNodeBehavior.java,v 1.3 1999/08/04 09:08:52 jsmthng Exp $
 */
class IntermediateNodeBehavior implements NodeBehavior {

  private boolean readyToWrite;
  private int nextInIndex, nextOutIndex;
  private Object packetToBeSent;

  private void readFromChannel(InputChannelVector inputChannels) {
      
    // If there's no input stream, exit right away.
    if (inputChannels.size() == 0) return;
    for (int i = 0; i < inputChannels.size() && !readyToWrite; i++) {
      try { 
	packetToBeSent = 
	  inputChannels.elementAt(nextInIndex).readObject(); // ()?
	readyToWrite = true;
      }
      catch(ChannelEmptyException exc) {}
      catch(ChannelDisabledException exc2) {}
      catch(ArrayIndexOutOfBoundsException exc3) {}

      nextInIndex = (nextInIndex + 1) % inputChannels.size();
      // or, if you want to be really grotesque (Todd says cool):
      // nextInIndex = ++nextInputStream % inputChannels.size();
    }
  }


  private void writeToChannel(OutputChannelVector outputChannels) {

    if (outputChannels.size() == 0) return;
    for (int i = 0; i < outputChannels.size() && readyToWrite; i++) {
      try { 
		outputChannels.elementAt(nextOutIndex).writeObject( packetToBeSent ); // ()?
	readyToWrite = false;
      } 
      catch(ChannelFullException exc) {}
      catch(ChannelDisabledException exc2) {}
      catch(ArrayIndexOutOfBoundsException exc3) {}

      nextOutIndex = ++nextOutIndex % outputChannels.size();
      // or, if you want to be verbose and clear (Lynn says cool):
      // nextOutIndex = (nextOutIndex + 1) % outputChannels.size();
    }
  }

  public void transmitPacket(InputChannelVector inputs, OutputChannelVector outputs) {

    if (readyToWrite)           { writeToChannel( outputs ); }
    else /* not readyToWrite */ { readFromChannel( inputs ); }
  }
}

/*
 * $Log: IntermediateNodeBehavior.java,v $
 * Revision 1.3  1999/08/04 09:08:52  jsmthng
 * Added javadoc comments to InputChannelVector and OutputChannelVector;
 * finished updating the rest of the nodeNet package to reflect new
 * changes in name and code.
 *
 * Modified index.html to reflect the new nodeNet code, as well as to
 * clarify some parts of the problem set.
 *
 * Revision 1.1  1999/07/30 01:09:21  jsmthng
 * Renaming BinSort package to nodeNet; moving directories and files as
 * necessary.
 *
 * Revision 1.5  1998/08/12 19:29:36  tparnell
 * Another pass after comments from las & natashao.  Added support to
 * dynamically add NodeBehaviors.  Add keyboard shortcuts to menus.  Added
 * workaround to jdk bug relating to lighweight components.  Misc other
 * bugfixes.
 *
 * Revision 1.3  1998/08/10 17:45:50  tparnell
 * Revision to use JDK1.2 and Swing.  Redesign of GUI.  Removed old kludge
 * for file I/O and replaced with object serialization.  Channel no longer
 * requires animacy.  Removed unnessary dependencies between classes.
 * Added ability to configure channel's latency and capacity.  Added
 * javadoc to all files.  General code cleanup.
 *
 */