/*
 * OutputChannel.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

/** 
 * This is the interface to put objects into a channel.  It defines one
 * method, <code>writeObject()</code>.<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Techonology
 *
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: OutputChannel.java,v 1.3 1999/08/04 09:08:54 jsmthng Exp $ 
 */
public interface OutputChannel {

  /** 
   * Attempt to place an object into the channel.  Note that you can
   * place any object into a channel, though you probably only want to
   * deal with the packets Generators create.
   *
   * @param o the object to insert
   *
   * @throws ChannelFullException if the channel is full and cannot
   * accept more objects
   *
   * @throws ChannelDisabledException if the user has disabled the
   * channel
   */
  public void writeObject(Object o) throws ChannelFullException, 
    ChannelDisabledException;
}

/*
 * $Log: OutputChannel.java,v $
 * Revision 1.3  1999/08/04 09:08:54  jsmthng
 * Added javadoc comments to InputChannelVector and OutputChannelVector;
 * finished updating the rest of the nodeNet package to reflect new
 * changes in name and code.
 *
 * Modified index.html to reflect the new nodeNet code, as well as to
 * clarify some parts of the problem set.
 *
 * Revision 1.1  1999/07/30 01:09:23  jsmthng
 * Renaming BinSort package to nodeNet; moving directories and files as
 * necessary.
 *
 * Revision 1.3  1998/08/12 19:29:40  tparnell
 * Another pass after comments from las & natashao.  Added support to
 * dynamically add NodeBehaviors.  Add keyboard shortcuts to menus.  Added
 * workaround to jdk bug relating to lighweight components.  Misc other
 * bugfixes.
 *
 * Revision 1.3  1998/08/10 17:45:50  tparnell
 * Revision to use JDK1.2 and Swing.  Redesign of GUI.  Removed old kludge
 * for file I/O and replaced with object serialization.  Channel no longer
 * requires animacy.  Removed unnessary dependencies between classes.
 * Added ability to configure channel's latency and capacity.  Added
 * javadoc to all files.  General code cleanup.
 *
 */
