/*
 * OutputChannelVector.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1997 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.util.*;

/**
 * OutputChannelVector is something which acts like a <code>Vector</code>
 * of <code>OutputChannel</code>s instead of Objects.<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: OutputChannelVector.java,v 1.2 1999/08/04 09:08:54 jsmthng Exp $ 
 */
public class OutputChannelVector {

	private Vector myVector;
	
	/**
	 * Constructs a new OutputChannelVector
	 */
	public OutputChannelVector( )
	{
		this.myVector = new Vector( );
	}
	
	/**
	 * Adds an object to the OutputChannelVector.
	 */
	public final synchronized void addElement( Object obj )
	{
		this.myVector.addElement( obj );
	}
	
	/**
	 * Checks to see if it contains an element.
	 */
	public final boolean contains( Object elem )
	{
		return this.myVector.contains( elem );
	}
	
	/**
	 * Returns the OutputChannel at a certain index.
	 *
	 * @param index index of the OutputChannel being looked up
	 */
	public final synchronized OutputChannel elementAt( int index )
	{
		return (OutputChannel)this.myVector.elementAt( index );
	}
	
	/**
	 * Transforms OutputChannelVector into yet another type
	 * of collection of objects, called an Enumeration.
	 */		
	public final synchronized Enumeration elements( ) // allows to turn into another type of collection?? thingie
	{
		return this.myVector.elements( ); // should return Enum of IChannels?
	}
	
	/**
	 * Returns the first OutputChannel in the OutputChannelVector.
	 */
	public final synchronized OutputChannel firstElement( )
	{
		return (OutputChannel)this.myVector.firstElement( );
	}
	
	/**
	 * Returns true if the OutputChannelVector is empty.
	 */
	public final boolean isEmpty( )
	{
		return this.myVector.isEmpty( );
	}
	
	/**
	 * Returns the last OutputChannel in the OutputChannelVector.
	 */
	public final synchronized OutputChannel lastElement( )
	{
		return (OutputChannel)this.myVector.lastElement( );
	}
	
	/**
	 * Removes all elements from the OutputChannelVector.
	 */	
	public final synchronized void removeAllElements( )
	{
		this.myVector.removeAllElements( );
	}
	
	/**
	 * Removes a specific element from the OutputChannelVector.
	 *
	 * @param obj the object being removed
	 */
	public final synchronized boolean removeElement( Object obj )
	{
		return this.myVector.removeElement( obj );
	}
	
	/**
	 * Returns the size of the InputChannelVector.
	 */
	public final int size( )
	{
		return this.myVector.size( );
	}
}

/*
 * $Log:
 */