/*
 * TerminatorNodeBehavior.java
 * Part of the nodeNet problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package nodeNet;

import java.awt.*;
import java.util.Vector;

/**
 * This class is the NodeBehavior for a TerminatorNode.<p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: TerminatorNodeBehavior.java,v 1.3 1999/08/04 09:08:55 jsmthng Exp $
 */
class TerminatorNodeBehavior implements NodeBehavior, CountingNodeBehavior {
  private int num_des;
    
  public void transmitPacket(InputChannelVector inputChannels, OutputChannelVector outputChannels ) {
    int numInputChannels = inputChannels.size();
    int numOutputChannels = outputChannels.size();
    
    int in_number;
    boolean found = false;
    Object o;
    
    // If no inputs 
    if (numInputChannels == 0) return;
    
    // sometimes, just bail
    if (Math.random() < 0.6) return;
	
    for (int i = 0; i < 20; i++) {
      in_number = (int)(Math.random() * numInputChannels);
      try {
	o = inputChannels.elementAt(in_number).readObject(); // ()?
	this.num_des += 1;
      }
      catch(ChannelEmptyException exc) { return; }
      catch(ChannelDisabledException exc2) { return; }
    }
  }
  
  public int getCount() { return(this.num_des); }
  public void resetCount() { this.num_des = 0; }
}

/*
 * $Log: TerminatorNodeBehavior.java,v $
 * Revision 1.3  1999/08/04 09:08:55  jsmthng
 * Added javadoc comments to InputChannelVector and OutputChannelVector;
 * finished updating the rest of the nodeNet package to reflect new
 * changes in name and code.
 *
 * Modified index.html to reflect the new nodeNet code, as well as to
 * clarify some parts of the problem set.
 *
 * Revision 1.1  1999/07/30 01:09:24  jsmthng
 * Renaming BinSort package to nodeNet; moving directories and files as
 * necessary.
 *
 * Revision 1.4  1998/08/12 19:29:44  tparnell
 * Another pass after comments from las & natashao.  Added support to
 * dynamically add NodeBehaviors.  Add keyboard shortcuts to menus.  Added
 * workaround to jdk bug relating to lighweight components.  Misc other
 * bugfixes.
 *
 * Revision 1.3  1998/08/10 17:45:50  tparnell
 * Revision to use JDK1.2 and Swing.  Redesign of GUI.  Removed old kludge
 * for file I/O and replaced with object serialization.  Channel no longer
 * requires animacy.  Removed unnessary dependencies between classes.
 * Added ability to configure channel's latency and capacity.  Added
 * javadoc to all files.  General code cleanup.
 *
 */